artlib.modulation

This namespace houses higher-order functions for creating modulation generators. A modulation generator is a function hat accepts timing information and returns a value between 0.0 and 1.0. Think an ADSR Envelope.

Supplied values should be considered durations and not instances.

The returned modulation generators expect inputs relative to their lifecycle, not relative to the start of the application. I.e. pass a diff from when the event happens, not the event time.

Time units are in milliseconds.

This namespace houses higher-order functions for creating
  modulation generators. A modulation generator is a function
  hat accepts timing information and returns a value between
  0.0 and 1.0. Think an ADSR Envelope. 

Supplied values should be considered durations and not
  instances.

The returned modulation generators expect inputs relative to 
  their lifecycle, not relative to the start of the application.
  I.e. pass a diff from when the event happens, not the event 
  time.

Time units are in milliseconds.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries