(accelerator)Get hardware accelerator or nil if one is not provided.
Get hardware accelerator or nil if one is not provided.
(create-accelerator)Create and cache a harware accelerator, returning it. If none is available, returns nil.
Create and cache a harware accelerator, returning it. If none is available, returns nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |