Clojure bindings for OpenSimplex2 noise functions. All functions take an optional seed value and return noise in the range [-1, 1]. When seed is not provided, uses value from global seed atom.
Clojure bindings for OpenSimplex2 noise functions. All functions take an optional seed value and return noise in the range [-1, 1]. When seed is not provided, uses value from global seed atom.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |