(gauss mean variance)Samples a single value from a Gaussian distribution with the given mean and variance
Samples a single value from a Gaussian distribution with the given mean and variance
(with-matrix & body)(with-style & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |